@@ -24,13 +24,11 @@ from z2n.series import Series
 data = Series()
 figure = Plot()
 
-# Variables to display on the CLI
 __z2n__ = f'''
-        Z2n Software ({__version__}), a python program for periodograms analysis.
+        Z2n Software ({__version__}), a python package for periodograms analysis.
         Copyright (C) 2020, and MIT License, by Yohan Alexander [UFS].
         Type "help" for more information or "docs" for documentation.
         '''
-
 __plt__ = f'''
         Interactive plotting window of the Z2n Software ({__version__}).
         Type "help" for more information.
@@ -140,11 +138,11 @@ def z2n(input_, output_, format_, fmin, fmax, delta, over,
                     click.secho('Periodogram calculated.', fg='green')
                     click.secho(
                         "Values based on the global maximum.", fg='yellow')
-                    data.set_potency()
+                    data.set_power()
                     data.set_frequency()
                     data.set_period()
                     data.set_pfraction()
-                    data.get_potency()
+                    data.get_power()
                     data.get_frequency()
                     data.get_period()
                     data.get_pfraction()
@@ -197,11 +195,19 @@ def z2n(input_, output_, format_, fmin, fmax, delta, over,
         else:
             try:
                 figure.data.input = database['input']
+                figure.data.fmin = database['fmin']
+                figure.data.fmax = database['fmax']
+                figure.data.delta = database['delta']
+                figure.data.oversample = database['oversample']
             except KeyError:
                 pass
             click.echo(__z2n__)
             figure.plot_periodogram()
             database['input'] = figure.data.input
+            database['fmin'] = figure.data.fmin
+            database['fmax'] = figure.data.fmax
+            database['delta'] = figure.data.delta
+            database['oversample'] = figure.data.oversample
 
 
 @z2n.command()
@@ -224,13 +230,12 @@ def plot() -> None:
 @z2n.command()
 def run() -> None:
     """Calculate the Z2n Statistics."""
-    if not figure.plot_periodogram():
-        plt()
+    figure.plot_periodogram()
 
 
 @z2n.command()
-def log() -> None:
-    """Save the fit of a gaussian curve."""
+def gauss() -> None:
+    """Select the fit of a gaussian curve."""
     if figure.data.z2n.size == 0:
         click.secho("The periodogram was not calculated yet.", fg='yellow')
     else:
